# Changelog for Rich-Pyfiglet

## 0.1.4

- Merged the Big type hinting and modernization upgrade from Pyfiglet upstream (written by me, my first major contribution to Pyfiglet)

## 0.1.3

- Added some docstrings to some of the utility methods and marked all the internal rendering/animation methods as private using an underscore.

## 0.1.2

- Fixed mistake in docstring from not updating to match new parameters.

## 0.1.0

- Start of package - split Rich-Pyfiglet out from Textual-Pyfiglet.
